@@ -359,18 +359,26 @@ func (c *Controller) unseal(ctx context.Context, key string) (unsealErr error) {
 	secret = secret.DeepCopy()
 
 	if isAnnotatedToBePatched(secret) {
+		if secret.Data == nil {
+			secret.Data = make(map[string][]byte)
+		}
+
 		for k, v := range newSecret.Data {
 			secret.Data[k] = v
 		}
 
-		for k, v := range newSecret.ObjectMeta.Annotations {
-			secret.ObjectMeta.Annotations[k] = v
+		if secret.ObjectMeta.Labels == nil {
+			secret.ObjectMeta.Labels = make(map[string]string)
 		}
 
 		for k, v := range newSecret.ObjectMeta.Labels {
 			secret.ObjectMeta.Labels[k] = v
 		}
 
+		for k, v := range newSecret.ObjectMeta.Annotations {
+			secret.ObjectMeta.Annotations[k] = v
+		}
+
 		if isAnnotatedToBeManaged(secret) {
 			secret.ObjectMeta.OwnerReferences = newSecret.ObjectMeta.OwnerReferences
 		}
@@ -459,15 +467,11 @@ func updateSealedSecretsStatusConditions(st *ssv1alpha1.SealedSecretStatus, unse
 		cond.Message = unsealError.Error()
 	}
 
+	cond.LastUpdateTime = metav1.Now()
 	// Status has changed, update the transition time and signal that an update is required
 	if cond.Status != status {
-		if !cond.LastUpdateTime.IsZero() {
-			cond.LastTransitionTime = cond.LastUpdateTime
-		} else {
-			cond.LastTransitionTime = metav1.Now()
-		}
+		cond.LastTransitionTime = cond.LastUpdateTime
 		cond.Status = status
-		cond.LastUpdateTime = metav1.Now()
 		updateRequired = true
 	}
 
